@@ -1,8 +1,6 @@
 """
-Topic Models
-------------
-
-Convenient and consolidated topic-modeling, built on ``scikit-learn``.
+:mod:`textacy.tm.topic_model`: Convenient and consolidated topic-modeling,
+built on ``scikit-learn``.
 """
 import logging
 
@@ -10,7 +8,7 @@ import joblib
 import numpy as np
 from sklearn.decomposition import NMF, LatentDirichletAllocation, TruncatedSVD
 
-from .. import viz
+from .. import errors, viz
 
 LOGGER = logging.getLogger(__name__)
 
@@ -24,12 +22,12 @@ class TopicModel:
 
     Prepare a vectorized corpus (i.e. document-term matrix) and corresponding
     vocabulary (i.e. mapping of term strings to column indices in the matrix).
-    See :class:`textacy.vsm.Vectorizer` for details. In short:
+    See :class:`textacy.representations.vectorizers.Vectorizer` for details. In short:
 
     .. code-block:: pycon
 
         >>> vectorizer = Vectorizer(
-        ...     tf_type="linear", apply_idf=True, idf_type="smooth", norm="l2",
+        ...     tf_type="linear", idf_type="smooth", norm="l2",
         ...     min_df=3, max_df=0.95, max_n_terms=100000)
         >>> doc_term_matrix = vectorizer.fit_transform(terms_list)
 
@@ -116,7 +114,10 @@ class TopicModel:
     def __init__(self, model, n_topics=10, **kwargs):
         if isinstance(model, (NMF, LatentDirichletAllocation, TruncatedSVD)):
             self.model = model
-        elif all(hasattr(model, required_attr) for required_attr in self._required_trained_model_attr):
+        elif all(
+            hasattr(model, required_attr)
+            for required_attr in self._required_trained_model_attr
+        ):
             self.model = model
         else:
             self.init_model(model, n_topics=n_topics, **kwargs)
@@ -149,8 +150,9 @@ class TopicModel:
                 random_state=kwargs.get("random_state", 1),
             )
         else:
-            msg = 'model "{}" invalid; must be {}'.format(model, {"nmf", "lda", "lsa"})
-            raise ValueError(msg)
+            raise ValueError(
+                errors.value_invalid_msg("model", model, {"nmf", "lda", "lsa"})
+            )
 
     def __repr__(self):
         return "TopicModel(n_topics={}, model={})".format(
@@ -164,7 +166,9 @@ class TopicModel:
     @classmethod
     def load(cls, filepath):
         model = joblib.load(filepath)
-        n_topics = model.n_components if hasattr(model, "n_components") else model.n_topics
+        n_topics = (
+            model.n_components if hasattr(model, "n_components") else model.n_topics
+        )
         return cls(model, n_topics=n_topics)
 
     def fit(self, doc_term_matrix):
@@ -455,17 +459,16 @@ class TopicModel:
                 if topic_ind in topic_inds
             )
         else:
-            msg = "invalid sort_topics_by value; must be in {}".format(
-                {"index", "weight"}
+            raise ValueError(
+                errors.value_invalid_msg(
+                    "sort_topics_by", sort_topics_by, {"index", "weight"},
+                )
             )
-            raise ValueError(msg)
 
         # get column index of any topics to highlight in termite plot
         if highlight_topics is not None:
             highlight_cols = tuple(
-                i
-                for i in range(len(topic_inds))
-                if topic_inds[i] in highlight_topics
+                i for i in range(len(topic_inds)) if topic_inds[i] in highlight_topics
             )
         else:
             highlight_cols = None
@@ -480,10 +483,11 @@ class TopicModel:
                 : -n_terms - 1 : -1
             ]
         else:
-            msg = "invalid rank_terms_by value; must be in {}".format(
-                {"corpus_weight", "topic_weight"}
+            raise ValueError(
+                errors.value_invalid_msg(
+                    "rank_terms_by", rank_terms_by, {"corpus_weight", "topic_weight"},
+                )
             )
-            raise ValueError(msg)
 
         # get top term indices in sorted order
         if sort_terms_by == "weight":
@@ -518,10 +522,13 @@ class TopicModel:
             # get permutation corresponding to sorting the 2nd eigenvector
             term_inds = [term_inds[i] for i in np.argsort(fiedler)]
         else:
-            msg = "invalid sort_terms_by value; must be in {}".format(
-                {"weight", "index", "alphabetical", "seriation"}
+            raise ValueError(
+                errors.value_invalid_msg(
+                    "sort_terms_by",
+                    sort_terms_by,
+                    {"weight", "index", "alphabetical", "seriation"},
+                )
             )
-            raise ValueError(msg)
 
         # get topic and term labels
         topic_labels = tuple("topic {}".format(topic_ind) for topic_ind in topic_inds)
